package com.qcloud.tencent_tpns_xiaomi_push_plugin;

import android.content.Context;

import androidx.annotation.NonNull;

import com.xiaomi.mipush.sdk.MiPushClient;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** TencentTpnsXiaomiPushPlugin */
public class TencentTpnsXiaomiPushPlugin implements FlutterPlugin, MethodCallHandler {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;
  private Context context;

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    this.channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "tencent_tpns_xiaomi_push_plugin");
    channel.setMethodCallHandler(this);
    this.context = flutterPluginBinding.getApplicationContext();
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    if(call.method.equals("registerPush")){
      this.registerPush(call,result);
    } else if(call.method.equals("unregisterPush")){
      this.unregisterPush(result);
    } else if(call.method.equals("enablePush")){
      this.enablePush(result);
    } else if(call.method.equals("disablePush")){
      this.disablePush(result);
    } else if(call.method.equals("setAlias")){
      this.setAlias(call,result);
    } else if(call.method.equals("unsetAlias")){
      this.unsetAlias(call,result);
    } else if(call.method.equals("setUserAccount")){
      this.setUserAccount(call,result);
    } else if(call.method.equals("unsetUserAccount")){
      this.unsetUserAccount(call,result);
    } else if(call.method.equals("subscribe")){
      this.subscribe(call,result);
    } else if(call.method.equals("unsubscribe")){
      this.unsubscribe(call,result);
    } else if(call.method.equals("pausePush")){
      this.pausePush(call,result);
    } else if(call.method.equals("resumePush")){
      this.resumePush(call,result);
    } else if(call.method.equals("setAcceptTime")){
      this.setAcceptTime(call,result);
    } else if(call.method.equals("getAllAlias")){
      this.getAllAlias(result);
    } else if(call.method.equals("getAllTopic")){
      this.getAllTopic(result);
    } else if(call.method.equals("getAllUserAccount")){
      this.getAllUserAccount(result);
    } else if(call.method.equals("clearNotification")){
      this.clearNotification(call,result);
    } else if(call.method.equals("setLocalNotificationType")){
      this.setLocalNotificationType(call,result);
    } else if(call.method.equals("clearLocalNotificationType")){
      this.clearLocalNotificationType(result);
    } else if(call.method.equals("getRegId")){
      this.getRegId(result);
    }else {
      result.notImplemented();
    }
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }

  private void registerPush(@NonNull MethodCall call, @NonNull Result result){
    String appID = this.getParamByKey(call,"appID");
    String appToken = this.getParamByKey(call,"appToken");
    MiPushClient.registerPush(context,appID,appToken);
    result.success(null);
  }
  private void unregisterPush(@NonNull Result result){
    MiPushClient.unregisterPush(context);
    result.success(null);
  }
  private void enablePush(@NonNull Result result){
    MiPushClient.enablePush(context);
    result.success(null);
  }
  private void disablePush(@NonNull Result result){
    MiPushClient.disablePush(context);
    result.success(null);
  }
  private void setAlias(@NonNull MethodCall call,@NonNull Result result){
    String alias = this.getParamByKey(call,"alias");
    String category = this.getParamByKey(call,"category");
    MiPushClient.setAlias(context,alias,category);
    result.success(null);
  }
  private void unsetAlias(@NonNull MethodCall call,@NonNull Result result){
    String alias = this.getParamByKey(call,"alias");
    String category = this.getParamByKey(call,"category");
    MiPushClient.unsetAlias(context,alias,category);
    result.success(null);
  }
  private void setUserAccount(@NonNull MethodCall call,@NonNull Result result){
    String userAccount = this.getParamByKey(call,"userAccount");
    String category = this.getParamByKey(call,"category");
    MiPushClient.setUserAccount(context,userAccount,category);
    result.success(null);
  }
  private void unsetUserAccount(@NonNull MethodCall call,@NonNull Result result){
    String userAccount = this.getParamByKey(call,"userAccount");
    String category = this.getParamByKey(call,"category");
    MiPushClient.unsetUserAccount(context,userAccount,category);
    result.success(null);
  }
  private void subscribe(@NonNull MethodCall call,@NonNull Result result){
    String topic = this.getParamByKey(call,"topic");
    String category = this.getParamByKey(call,"category");
    MiPushClient.unsetUserAccount(context,topic,category);
    result.success(null);
  }
  private void unsubscribe(@NonNull MethodCall call,@NonNull Result result){
    String topic = this.getParamByKey(call,"topic");
    String category = this.getParamByKey(call,"category");
    MiPushClient.unsubscribe(context,topic,category);
    result.success(null);
  }
  private void pausePush(@NonNull MethodCall call,@NonNull Result result){
    String category = this.getParamByKey(call,"category");
    MiPushClient.pausePush(context,category);
    result.success(null);
  }
  private void resumePush(@NonNull MethodCall call,@NonNull Result result){
    String category = this.getParamByKey(call,"category");
    MiPushClient.resumePush(context,category);
    result.success(null);
  }
  private void setAcceptTime(@NonNull MethodCall call,@NonNull Result result){
    int startHour = this.getParamByKey(call,"startHour");
    int startMin = this.getParamByKey(call,"startMin");
    int endHour = this.getParamByKey(call,"endHour");
    int endMin = this.getParamByKey(call,"endMin");
    String category = this.getParamByKey(call,"category");
    MiPushClient.setAcceptTime(context,startHour,startMin,endHour,endMin,category);
    result.success(null);
  }
  private void getAllAlias(@NonNull Result result){
    result.success(MiPushClient.getAllAlias(context));
  }
  private void getAllTopic(@NonNull Result result){
    result.success(MiPushClient.getAllTopic(context));
  }
  private void getAllUserAccount(@NonNull Result result){
    result.success(MiPushClient.getAllUserAccount(context));
  }
  private void clearNotification(@NonNull MethodCall call,@NonNull Result result){
    int notifyId = this.getParamByKey(call,"notifyId");
    if(this.getParamByKey(call,"notifyId")==null){
      MiPushClient.clearNotification(context);
    }else{
      MiPushClient.clearNotification(context,notifyId);
    }
    result.success(null);
  }
  private void setLocalNotificationType(@NonNull MethodCall call,@NonNull Result result){
    int notifyType = this.getParamByKey(call,"notifyType");
    MiPushClient.setLocalNotificationType(context,notifyType);
    result.success(null);
  }
  private void clearLocalNotificationType(@NonNull Result result){
    MiPushClient.clearLocalNotificationType(context);
    result.success(null);
  }
  private void getRegId(@NonNull Result result){
    result.success(MiPushClient.getRegId(context));
  }
  private <T> T getParamByKey(@NonNull MethodCall methodCall, String key) {
    T par = methodCall.argument(key);
    return par;
  }
}
