import 'dart:async';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class TencentTpnsXiaomiPushPlugin {
  static const MethodChannel _channel =
      const MethodChannel('tencent_tpns_xiaomi_push_plugin');

  ///注册MiPush推送服务。详细说明请参见3.4.1。
  ///
  ///由开发者决定是否注册推送。
  ///
  static void registerPush({
    @required String appID,
    @required String appToken,
  }) {
    _channel.invokeMethod("registerPush", {
      "appID": appID,
      "appToken": appToken,
    });
  }

  ///关闭MiPush推送服务。详细说明请参见3.4.2。
  ///
  ///由开发者决定是否关闭推送。
  ///
  static void unregisterPush() {
    _channel.invokeMethod("unregisterPush");
  }

  ///启用MiPush推送服务。详细说明请参见3.4.27。调用disablePush和enablePush接口后，不会生成新的regId，regId会和原来的保持一致。
  ///
  ///由开发者决定是否启用推送。
  ///
  static void enablePush() {
    _channel.invokeMethod("enablePush");
  }

  ///禁用MiPush推送服务。详细说明请参见3.4.28。调用disablePush和enablePush接口后，不会生成新的regId，regId会和原来的保持一致。
  ///
  ///由开发者决定是否禁用推送。
  ///
  static void disablePush() {
    _channel.invokeMethod("disablePush");
  }

  ///为指定用户设置alias。详细说明请参见3.4.3。
  ///
  ///开发者决定通过alias推送。
  ///
  static void setAlias({
    @required String alias,
    @required String category,
  }) {
    _channel.invokeMethod("setAlias", {
      "alias": alias,
      "category": category,
    });
  }

  ///取消指定用户的alias。详细说明请参见3.4.4。
  ///
  ///开发者需要取消用户别名。
  ///
  static void unsetAlias({
    @required String alias,
    @required String category,
  }) {
    _channel.invokeMethod("unsetAlias", {
      "alias": alias,
      "category": category,
    });
  }

  ///为指定用户设置userAccount。详细说明请参见3.4.5。
  ///
  ///开发者决定通过userAccount推送。
  ///
  static void setUserAccount({
    @required String userAccount,
    @required String category,
  }) {
    _channel.invokeMethod("setUserAccount", {
      "userAccount": userAccount,
      "category": category,
    });
  }

  ///取消指定用户的userAccount。详细说明请参见3.4.6。
  ///
  ///开发者需要取消用户userAccount。
  ///
  static void unsetUserAccount({
    @required String userAccount,
    @required String category,
  }) {
    _channel.invokeMethod("unsetUserAccount", {
      "userAccount": userAccount,
      "category": category,
    });
  }

  ///为某个用户设置订阅topic。详细说明请参见3.4.7。
  ///
  ///按照用户的订阅，开发者实现根据订阅分组群发。
  ///
  static void subscribe({
    @required String topic,
    @required String category,
  }) {
    _channel.invokeMethod("subscribe", {
      "topic": topic,
      "category": category,
    });
  }

  ///取消某个用户的订阅topic。详细说明请参见3.4.8。
  ///
  ///用户取消某个订阅topic。
  ///
  static void unsubscribe({
    @required String topic,
    @required String category,
  }) {
    _channel.invokeMethod("unsubscribe", {
      "topic": topic,
      "category": category,
    });
  }

  ///暂停接收MiPush服务推送的消息。详细说明请参见3.4.10。
  ///
  ///app在恢复MiPush推送服务之前，不接收任何推送消息。
  ///
  static void pausePush({
    @required String category,
  }) {
    _channel.invokeMethod("pausePush", {
      "category": category,
    });
  }

  ///恢复接收MiPush服务推送的消息，这时服务器会把暂停时期的推送消息重新推送过来。详细说明请参见3.4.11。
  ///
  ///恢复接收MiPush服务推送消息。
  ///
  static void resumePush({
    @required String category,
  }) {
    _channel.invokeMethod("resumePush", {
      "category": category,
    });
  }

  ///设置接收MiPush服务推送的时段，不在该时段的推送消息会被缓存起来，到了合适的时段再向app推送原先被缓存的消息。详细说明请参见3.4.9。
  ///
  ///用户可以控制什么时段接收推送消息。
  ///
  static void setAcceptTime({
    @required int startHour,
    @required int startMin,
    @required int endHour,
    @required int endMin,
    @required String category,
  }) {
    _channel.invokeMethod("setAcceptTime", {
      "startHour": startHour,
      "startMin": startMin,
      "endHour": endHour,
      "endMin": endMin,
      "category": category,
    });
  }

  ///方法返回了客户端设置的别名列表(如果客户端没有设置别名，则返回空列表)。详细说明请参见3.4.12。
  ///
  ///开发者需要查询所设置的别名。
  ///
  static Future<List<String>> getAllAlias() async {
    return await _channel.invokeMethod("getAllAlias");
  }

  ///方法返回了客户端订阅的主题列表(如果客户端没有订阅主题，则返回空列表)。详细说明请参见3.4.13。
  ///
  ///开发者需要查询所订阅的主题。
  ///
  static Future<List<String>> getAllTopic() async {
    return await _channel.invokeMethod("getAllTopic");
  }

  ///获取客户端所有设置的帐号。详细说明请参见3.4.14。
  ///
  ///开发者需要查询所设置的账号。
  ///
  static Future<List<String>> getAllUserAccount() async {
    return await _channel.invokeMethod("getAllUserAccount");
  }

  ///清除小米推送弹出的某一个notifyId通知。详细说明请参见3.4.16。
  ///
  ///清除小米推送弹出的某一个notifyId通知。
  ///
  static void clearNotification({
    int notifyId,
  }) {
    _channel.invokeMethod("clearNotification", {
      "notifyId": notifyId,
    });
  }

  ///客户端设置通知消息的提醒类型。注：当服务端指定了消息的提醒类型，会优选考虑客户端设置的。详细说明请参见3.4.18。
  ///
  ///客户端设置通知消息的提醒类型。
  ///
  static void setLocalNotificationType({
    @required int notifyType,
  }) {
    _channel.invokeMethod("setLocalNotificationType", {
      "notifyType": notifyType,
    });
  }

  ///清除客户端设置的通知消息提醒类型。详细说明请参见3.4.19。
  ///
  ///清除客户端设置的通知消息提醒类型。
  ///
  static void clearLocalNotificationType() {
    _channel.invokeMethod("clearLocalNotificationType");
  }

  ///获取客户端的RegId。详细说明请参见3.4.20。
  ///
  ///获取客户端的RegId。
  ///
  static Future<String> getRegId() async {
    return await _channel.invokeMethod("getRegId");
  }
}
